@@ -3,15 +3,17 @@
 use warnings;
 use strict;
 
-use lib qw(../lib);
+use FindBin qw($Bin);
+
+use lib "$Bin/../lib";
 
 use Log::Log4perl;
 
-Log::Log4perl::init("log.conf");
+Log::Log4perl::init("$Bin/log.conf");
 
-my $log = Log::Log4perl->get_logger("producer");
+my $log = Log::Log4perl->get_logger('producer');
 
-my @levels = ("debug", "info", "warn", "error", "fatal");
+my @levels = ('debug', 'info', 'warn', 'error', 'fatal');
 
 my @alpha  = ('A' .. 'Z');
 my $prefix = 1;
@@ -22,7 +24,7 @@ while ($count < 500) {
 
     my $method_name = $levels[ int(rand(5)) ];
 
-    my $msg = sprintf("%s", $alpha[$index]) x $prefix;
+    my $msg = sprintf('%s', $alpha[$index]) x $prefix;
 
     $index++;
 
@@ -33,10 +35,10 @@ while ($count < 500) {
     }
 
     {
-        no strict 'refs';
+        no strict 'refs'; ## no critic
 
         $log->$method_name($msg);
     }
 
-    sleep(sprintf("%.1f", rand(1)));
+    sleep(sprintf('%.1f', rand(1)));
 }
